@@ -1,3 +1,5 @@
+// -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
+// vi: set et ts=4 sw=2 sts=2:
 #include "float_cmp.hh"
 
 #include <vector>
@@ -17,7 +19,7 @@ namespace Dune {
      * @tparam T The value type
      */
     template<class T> struct EpsilonType {
-     //! The epsilon type corresponding to value type T
+      //! The epsilon type corresponding to value type T
       typedef T Type;
     };
     //! Specialization of EpsilonType for std::vector
@@ -116,64 +118,88 @@ namespace Dune {
     bool eq(const T &first,
             const T &second,
             typename EpsilonType<T>::Type epsilon)
-    { return Detail::eq_t<T, style>::eq(first, second, epsilon); }
+    {
+      return Detail::eq_t<T, style>::eq(first, second, epsilon);
+    }
     template <class T, CmpStyle style>
     bool ne(const T &first,
             const T &second,
             typename EpsilonType<T>::Type epsilon)
-    { return !eq<T, style>(first, second, epsilon); }
+    {
+      return !eq<T, style>(first, second, epsilon);
+    }
     template <class T, CmpStyle style>
     bool gt(const T &first,
             const T &second,
             typename EpsilonType<T>::Type epsilon)
-    { return first > second && ne<T, style>(first, second, epsilon); }
+    {
+      return first > second && ne<T, style>(first, second, epsilon);
+    }
     template <class T, CmpStyle style>
     bool lt(const T &first,
             const T &second,
             typename EpsilonType<T>::Type epsilon)
-    { return first < second && ne<T, style>(first, second, epsilon); }
+    {
+      return first < second && ne<T, style>(first, second, epsilon);
+    }
     template <class T, CmpStyle style>
     bool ge(const T &first,
             const T &second,
             typename EpsilonType<T>::Type epsilon)
-    { return first > second || eq<T, style>(first, second, epsilon); }
+    {
+      return first > second || eq<T, style>(first, second, epsilon);
+    }
     template <class T, CmpStyle style>
     bool le(const T &first,
             const T &second,
             typename EpsilonType<T>::Type epsilon)
-    { return first < second || eq<T, style>(first, second, epsilon); }
+    {
+      return first < second || eq<T, style>(first, second, epsilon);
+    }
 
     // default template arguments
     template <class T>
     bool eq(const T &first,
             const T &second,
             typename EpsilonType<T>::Type epsilon = DefaultEpsilon<T, defaultCmpStyle>::value())
-    { return eq<T, defaultCmpStyle>(first, second, epsilon); }
+    {
+      return eq<T, defaultCmpStyle>(first, second, epsilon);
+    }
     template <class T>
     bool ne(const T &first,
             const T &second,
             typename EpsilonType<T>::Type epsilon = DefaultEpsilon<T, defaultCmpStyle>::value())
-    { return ne<T, defaultCmpStyle>(first, second, epsilon); }
+    {
+      return ne<T, defaultCmpStyle>(first, second, epsilon);
+    }
     template <class T>
     bool gt(const T &first,
             const T &second,
             typename EpsilonType<T>::Type epsilon = DefaultEpsilon<T, defaultCmpStyle>::value())
-    { return gt<T, defaultCmpStyle>(first, second, epsilon); }
+    {
+      return gt<T, defaultCmpStyle>(first, second, epsilon);
+    }
     template <class T>
     bool lt(const T &first,
             const T &second,
             typename EpsilonType<T>::Type epsilon = DefaultEpsilon<T, defaultCmpStyle>::value())
-    { return lt<T, defaultCmpStyle>(first, second, epsilon); }
+    {
+      return lt<T, defaultCmpStyle>(first, second, epsilon);
+    }
     template <class T>
     bool ge(const T &first,
             const T &second,
             typename EpsilonType<T>::Type epsilon = DefaultEpsilon<T, defaultCmpStyle>::value())
-    { return ge<T, defaultCmpStyle>(first, second, epsilon); }
+    {
+      return ge<T, defaultCmpStyle>(first, second, epsilon);
+    }
     template <class T>
     bool le(const T &first,
             const T &second,
             typename EpsilonType<T>::Type epsilon = DefaultEpsilon<T, defaultCmpStyle>::value())
-    { return le<T, defaultCmpStyle>(first, second, epsilon); }
+    {
+      return le<T, defaultCmpStyle>(first, second, epsilon);
+    }
 
     // rounding operations
     namespace Detail {
@@ -216,7 +242,7 @@ namespace Dune {
         static I
         round(const T &val,
               typename EpsilonType<T>::Type epsilon = (DefaultEpsilon<T, cstyle>::value())) {
-          if(val > T(0)) 
+          if(val > T(0))
             return round_t<I, T, cstyle, downward>::round(val, epsilon);
           else return round_t<I, T, cstyle, upward>::round(val, epsilon);
         }
@@ -226,7 +252,7 @@ namespace Dune {
         static I
         round(const T &val,
               typename EpsilonType<T>::Type epsilon = (DefaultEpsilon<T, cstyle>::value())) {
-          if(val > T(0)) 
+          if(val > T(0))
             return round_t<I, T, cstyle, upward>::round(val, epsilon);
           else return round_t<I, T, cstyle, downward>::round(val, epsilon);
         }
@@ -257,16 +283,24 @@ namespace Dune {
     } // namespace Detail
     template<class I, class T, CmpStyle cstyle, RoundingStyle rstyle>
     I round(const T &val, typename EpsilonType<T>::Type epsilon /*= DefaultEpsilon<T, cstyle>::value()*/)
-    { return Detail::round_t<I, T, cstyle, rstyle>::round(val, epsilon); }
+    {
+      return Detail::round_t<I, T, cstyle, rstyle>::round(val, epsilon);
+    }
     template<class I, class T, CmpStyle cstyle>
     I round(const T &val, typename EpsilonType<T>::Type epsilon = DefaultEpsilon<T, cstyle>::value())
-    { return round<I, T, cstyle, defaultRoundingStyle>(val, epsilon); }
+    {
+      return round<I, T, cstyle, defaultRoundingStyle>(val, epsilon);
+    }
     template<class I, class T, RoundingStyle rstyle>
     I round(const T &val, typename EpsilonType<T>::Type epsilon = DefaultEpsilon<T, defaultCmpStyle>::value())
-    { return round<I, T, defaultCmpStyle, rstyle>(val, epsilon); }
+    {
+      return round<I, T, defaultCmpStyle, rstyle>(val, epsilon);
+    }
     template<class I, class T>
     I round(const T &val, typename EpsilonType<T>::Type epsilon = DefaultEpsilon<T, defaultCmpStyle>::value())
-    { return round<I, T, defaultCmpStyle>(val, epsilon); }
+    {
+      return round<I, T, defaultCmpStyle>(val, epsilon);
+    }
 
     // truncation
     namespace Detail {
@@ -345,16 +379,24 @@ namespace Dune {
     } // namespace Detail
     template<class I, class T, CmpStyle cstyle, RoundingStyle rstyle>
     I trunc(const T &val, typename EpsilonType<T>::Type epsilon /*= DefaultEpsilon<T, cstyle>::value()*/)
-    { return Detail::trunc_t<I, T, cstyle, rstyle>::trunc(val, epsilon); }
+    {
+      return Detail::trunc_t<I, T, cstyle, rstyle>::trunc(val, epsilon);
+    }
     template<class I, class T, CmpStyle cstyle>
     I trunc(const T &val, typename EpsilonType<T>::Type epsilon = DefaultEpsilon<T, cstyle>::value())
-    { return trunc<I, T, cstyle, defaultRoundingStyle>(val, epsilon); }
+    {
+      return trunc<I, T, cstyle, defaultRoundingStyle>(val, epsilon);
+    }
     template<class I, class T, RoundingStyle rstyle>
     I trunc(const T &val, typename EpsilonType<T>::Type epsilon = DefaultEpsilon<T, defaultCmpStyle>::value())
-    { return trunc<I, T, defaultCmpStyle, rstyle>(val, epsilon); }
+    {
+      return trunc<I, T, defaultCmpStyle, rstyle>(val, epsilon);
+    }
     template<class I, class T>
     I trunc(const T &val, typename EpsilonType<T>::Type epsilon = DefaultEpsilon<T, defaultCmpStyle>::value())
-    { return trunc<I, T, defaultCmpStyle>(val, epsilon); }
+    {
+      return trunc<I, T, defaultCmpStyle>(val, epsilon);
+    }
   } //namespace Dune
 
   // oo interface
@@ -366,55 +408,75 @@ namespace Dune {
   template<class T, FloatCmp::CmpStyle cstyle_, FloatCmp::RoundingStyle rstyle_>
   typename FloatCmpOps<T, cstyle_, rstyle_>::EpsilonType
   FloatCmpOps<T, cstyle_, rstyle_>::epsilon() const
-  { return epsilon_; }
+  {
+    return epsilon_;
+  }
 
   template<class T, FloatCmp::CmpStyle cstyle_, FloatCmp::RoundingStyle rstyle_>
   void
   FloatCmpOps<T, cstyle_, rstyle_>::epsilon(EpsilonType epsilon__)
-  { epsilon_ = epsilon__; }
+  {
+    epsilon_ = epsilon__;
+  }
 
 
   template<class T, FloatCmp::CmpStyle cstyle_, FloatCmp::RoundingStyle rstyle_>
   bool FloatCmpOps<T, cstyle_, rstyle_>::
   eq(const ValueType &first, const ValueType &second) const
-  { return Dune::FloatCmp::eq<ValueType, cstyle>(first, second, epsilon_); }
+  {
+    return Dune::FloatCmp::eq<ValueType, cstyle>(first, second, epsilon_);
+  }
 
   template<class T, FloatCmp::CmpStyle cstyle_, FloatCmp::RoundingStyle rstyle_>
   bool FloatCmpOps<T, cstyle_, rstyle_>::
   ne(const ValueType &first, const ValueType &second) const
-  { return Dune::FloatCmp::ne<ValueType, cstyle>(first, second, epsilon_); }
+  {
+    return Dune::FloatCmp::ne<ValueType, cstyle>(first, second, epsilon_);
+  }
 
   template<class T, FloatCmp::CmpStyle cstyle_, FloatCmp::RoundingStyle rstyle_>
   bool FloatCmpOps<T, cstyle_, rstyle_>::
   gt(const ValueType &first, const ValueType &second) const
-  { return Dune::FloatCmp::gt<ValueType, cstyle>(first, second, epsilon_); }
+  {
+    return Dune::FloatCmp::gt<ValueType, cstyle>(first, second, epsilon_);
+  }
 
   template<class T, FloatCmp::CmpStyle cstyle_, FloatCmp::RoundingStyle rstyle_>
   bool FloatCmpOps<T, cstyle_, rstyle_>::
   lt(const ValueType &first, const ValueType &second) const
-  { return Dune::FloatCmp::lt<ValueType, cstyle>(first, second, epsilon_); }
+  {
+    return Dune::FloatCmp::lt<ValueType, cstyle>(first, second, epsilon_);
+  }
 
   template<class T, FloatCmp::CmpStyle cstyle_, FloatCmp::RoundingStyle rstyle_>
   bool FloatCmpOps<T, cstyle_, rstyle_>::
   ge(const ValueType &first, const ValueType &second) const
-  { return Dune::FloatCmp::ge<ValueType, cstyle>(first, second, epsilon_); }
+  {
+    return Dune::FloatCmp::ge<ValueType, cstyle>(first, second, epsilon_);
+  }
 
   template<class T, FloatCmp::CmpStyle cstyle_, FloatCmp::RoundingStyle rstyle_>
   bool FloatCmpOps<T, cstyle_, rstyle_>::
   le(const ValueType &first, const ValueType &second) const
-  { return Dune::FloatCmp::le<ValueType, cstyle>(first, second, epsilon_); }
+  {
+    return Dune::FloatCmp::le<ValueType, cstyle>(first, second, epsilon_);
+  }
 
 
   template<class T, FloatCmp::CmpStyle cstyle_, FloatCmp::RoundingStyle rstyle_>
   template<class I>
   I FloatCmpOps<T, cstyle_, rstyle_>::
   round(const ValueType &val) const
-  { return Dune::FloatCmp::round<I, ValueType, cstyle, rstyle_>(val, epsilon_); }
+  {
+    return Dune::FloatCmp::round<I, ValueType, cstyle, rstyle_>(val, epsilon_);
+  }
 
   template<class T, FloatCmp::CmpStyle cstyle_, FloatCmp::RoundingStyle rstyle_>
   template<class I>
   I FloatCmpOps<T, cstyle_, rstyle_>::
   trunc(const ValueType &val) const
-  { return Dune::FloatCmp::trunc<I, ValueType, cstyle, rstyle_>(val, epsilon_); }
+  {
+    return Dune::FloatCmp::trunc<I, ValueType, cstyle, rstyle_>(val, epsilon_);
+  }
 
 } //namespace Dune
