@@ -1,32 +1,34 @@
+// -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
+// vi: set et ts=4 sw=2 sts=2:
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include<dune/common/mpihelper.hh>
-#include<iostream>
+#include <dune/common/parallel/mpihelper.hh>
+#include <iostream>
 
 int main(int argc, char** argv)
 {
 
-#ifdef MPIHELPER_PREINITIALIZE 
+#ifdef MPIHELPER_PREINITIALIZE
 #if HAVE_MPI
   MPI_Init(&argc, &argv);
 #endif
 #endif
 
   typedef Dune::MPIHelper Helper;
-  
-  {
-    Helper& mpi = Helper::instance(argc, argv);
-    
-    Helper::MPICommunicator comm = mpi.getCommunicator();
-    comm= mpi.getCommunicator();
-  }
-  
+
   {
     Helper& mpi = Helper::instance(argc, argv);
 
-    Helper::MPICommunicator comm= mpi.getCommunicator();
+    Helper::MPICommunicator comm DUNE_UNUSED = mpi.getCommunicator();
+    comm= mpi.getCommunicator();
+  }
+
+  {
+    Helper& mpi = Helper::instance(argc, argv);
+
+    Helper::MPICommunicator comm DUNE_UNUSED = mpi.getCommunicator();
     comm= mpi.getCommunicator();
 
 #ifdef MPIHELPER_PREINITIALIZE
@@ -36,5 +38,5 @@ int main(int argc, char** argv)
 #endif
   }
   std::cout << "We are at the end!"<<std::endl;
-  
+
 }
