@@ -1,3 +1,5 @@
+// -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
+// vi: set et ts=4 sw=2 sts=2:
 #include <config.h>
 
 #include <iostream>
@@ -6,9 +8,9 @@
 
 using namespace Dune;
 
-int main(int argc, char** argv) {
+int main(int, char**) {
   Dune::FieldVector<double,3> pos;
-  
+
   pos <<= 1, 0, 0;
 
   Dune::FieldVector<float,FVSIZE> pos2(pos);
